package
module
Version:
v0.0.0-...-2f2c24c
Opens a new window with list of versions in this module.
Published: Sep 10, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DCom interface {
AddService(service any)
Execute(execution any)
BlockingRun()
Run()
}
type Options interface {
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.